#include "printwidget.h"
#include <QApplication>
#include <QFile>
#include <QPrinter>
#include <QUrl>
#include <QDir>
#include <QDesktopServices>
#include <QPrintDialog>

PrintWidget::PrintWidget(QWidget *parent): QWebView(parent)
{
    const QString html_file = QDir::toNativeSeparators(qApp->applicationDirPath()+"/print.html");
    QFile file(html_file);
    if(file.open(QIODevice::ReadOnly))
    {
        this->setHtml(QString::fromUtf8(file.readAll()));

        QPrinter printer(QPrinter::HighResolution);
        printer.setColorMode(QPrinter::GrayScale);
        printer.setOrientation(QPrinter::Portrait);
        printer.setPageSize(QPrinter::A4);
        printer.setPaperSize(QPrinter::A4);
        printer.setPageMargins(12.7,12.7,12.7,12.7,QPrinter::Millimeter);

		/* Output to printer, xps printer, pdf printer, etc... is broken with this code */
        QPrintDialog dlg(&printer,this);
        dlg.exec();
		printer.setOutputFormat(QPrinter::NativeFormat);
        this->print(&printer);
		/* end broken printing */

		/* Outputs perfectly printed pdf file */
		printer.setOutputFileName(html_file+".pdf");
		printer.setOutputFormat(QPrinter::PdfFormat);
		this->print(&printer);
		/* end pdf printing */

        QDesktopServices::openUrl(QUrl::fromLocalFile(printer.outputFileName()));
    }
    file.close();
}

